@@ -26,7 +26,7 @@ from shake import url_for, Render
 __all__ = (
     'split_hash', 'generate_salt', 'pbkdf2',
     'hash_sha256', 'hash_sha512', 'hash_bcrypt', 'hash_scrypt',
-    'get_user_model', 'LazyUser', 'Token', 'auth_render',
+    'LazyUser', 'Token', 'auth_render',
 )
 
 
@@ -178,6 +178,14 @@ def hash_old_sha512(data, salt=None, cost=DEFAULT_COST):
     return 'sha512$%i$%s$%s' % (cost, salt, hashed)
 
 
+def get_user_hmac(user):
+    # This use as a seed a few chars from the password SALT.
+    # NOT from the real password.
+    mac = hashlib.sha256(user.password[10:18])
+    mac = mac.hexdigest()[:8]
+    return '%s$%s' % (user.id, mac)
+
+
 class LazyUser(object):
     """Loads the current user from the session, but only when needed.
     
@@ -188,7 +196,7 @@ class LazyUser(object):
 
     SESSION_NAME = '_uhm'
     
-    def __init__(self, db, User):
+    def __init__(self, app, db, User):
         self.db = db
         self.User = User
     
@@ -203,27 +211,9 @@ class LazyUser(object):
                     raise ValueError
             except ValueError:
                 user = None
-                request.session.invalidate()
+                self.app.session_interface.invalidate(request)
         request.user = user
         return user
-    
-    @classmethod
-    def get_user_hmac(cls, user):
-        # This use as a seed a few chars from the password SALT.
-        # NOT from the real password.
-        mac = hashlib.sha256(user.password[10:18])
-        mac = mac.hexdigest()[:8]
-        return '%s$%s' % (user.id, mac)
-    
-    @classmethod
-    def sign_in(cls, request, user):
-        request.session[cls.SESSION_NAME] = cls.get_user_hmac(user)
-        request.user = user
-    
-    @classmethod
-    def sign_out(cls, request):
-        request.session.invalidate()
-        request.user = None
 
 
 class Token(object):
@@ -244,44 +234,6 @@ class Token(object):
         return self.token
 
 
-def get_user_model(db):
-    """ """
-    class User(db.Model):
-        
-        id = db.Column(db.Integer, primary_key=True)
-        login = db.Column(db.Unicode(64),
-            unique=True, nullable=False)
-        email = db.Column(db.String(64),
-            nullable=True)
-        password = db.Column(db.String(140), nullable=True)
-        date_joined = db.Column(db.DateTime, default=datetime.utcnow,
-            nullable=False)
-        last_sign_in = db.Column(db.DateTime,
-            nullable=True)
-        status = db.Column(db.String(1),
-            default='A', nullable=False)
-        
-        def __init__(self, login, password=None, email=None):
-            self.login = login
-            self.password = password
-            self.email = email
-        
-        def __repr__(self):
-            if self.email:
-                return '<User %s (%s)>' % (self.login, self.email)
-            return '<User %s>' % self.login
-        
-        @property
-        def is_active(self):
-            return self.status == 'A'
-        
-        @property
-        def is_suspended(self):
-            return self.status == 'S'
-    
-    return User
-
-
 auth_loader = PackageLoader('shake_auth', 'templates')
 auth_render = Render(loader=auth_loader)
 
